==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AutoSave</name>
    <message>
        <location filename="../AutoSave.js" line="+34"/>
        <source>Load/Save</source>
        <translation>Carregue/Grave</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Autosave</source>
        <translation>Grave Automaticamente</translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Autosave failed:</source>
        <translation>Gravação automática falhou:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Gravação automática concluída.</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation>Um arquivo de backup de gravação automática para um desenho sem título foi encontrado.
Você deseja recuperá-lo?</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation>%1 arquivos de backup de gravação automática, para desenhos sem título foram encontrados.
Você deseja recuperá-los?</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Recovered</source>
        <translation>Recuperado</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Recuperar Arquivo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Um arquivo de backup de gravação automática para &apos;%1&apos; foi encontrado.
Você deseja recuperá-lo?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>Não é possível renomear o arquivo:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>Movido o arquivo de gravação automática para:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>Movido o arquivo original para:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>Não é possível excluir o arquivo:</translation>
    </message>
    <message>
        <source>Cannot remove file: </source>
        <translation type="obsolete">Não é possível excluir arquivo: </translation>
    </message>
    <message>
        <source>Cannot rename backup file: </source>
        <translation type="obsolete">Não é possível renomear o arquivo de backup:</translation>
    </message>
    <message>
        <source>Moved autosave backup file to: </source>
        <translation type="obsolete">Renomeado arquivo gravação automática:</translation>
    </message>
    <message>
        <location line="-124"/>
        <source>Recover Files?</source>
        <translation>Recupere os Arquivos?</translation>
    </message>
    <message>
        <source>Choose Autosave Directory</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Escolha diretório gravação automática</translation>
    </message>
    <message>
        <location line="-57"/>
        <source>Autosaving to:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Gravação automática para:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translatorcomment>--google--
Caixa de diálogo de comportamento (requer reinício):</translatorcomment>
        <translation>Habilite a gravação automática</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Intervalo para gravação automática:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translatorcomment>--google--
Indique o ponto de término do eixo menor:
Indique o ponto de término do eixo menor
Termine</translatorcomment>
        <translation>min</translation>
    </message>
    <message>
        <source>Autosave Directory:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Diretório:</translation>
    </message>
    <message>
        <source>auto</source>
        <translatorcomment>--exact match--
--file: GridSettings_pt.ts--
&amp;Automático
Automático
Salta automaticamente</translatorcomment>
        <translation type="obsolete">auto</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AutoSave</name>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Carregue/Grave</translation>
    </message>
    <message>
        <location filename="../AutoSave.js" line="+35"/>
        <source>Autosave</source>
        <translation>Grave Automaticamente</translation>
    </message>
    <message>
        <source>Open/Save</source>
        <translation type="vanished">Carregue/Grave</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Ficheiro</translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Autosave failed:</source>
        <translation>Gravação automática falhou:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Gravação automática concluída.</translation>
    </message>
    <message>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation type="vanished">Um arquivo de backup de gravação automática para um desenho sem título foi encontrado.
Você deseja recuperá-lo?</translation>
    </message>
    <message>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation type="vanished">%1 arquivos de backup de gravação automática, para desenhos sem título foram encontrados.
Você deseja recuperá-los?</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source>%n &apos;autosave&apos; backup file(s) for (an) untitled drawing(s) was/were found.
Do you wish to recover it/them?</source>
        <translation>
            <numerusform>Um arquivo de backup de gravação automática para um desenho sem título foi encontrado.
Você deseja recuperá-lo?</numerusform>
            <numerusform>%n arquivos de backup de gravação automática, para desenhos sem título foram encontrados.
Você deseja recuperá-los?</numerusform>
        </translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Recovered</source>
        <translation>Recuperado</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Recuperar Arquivo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Um arquivo de backup de gravação automática para &apos;%1&apos; foi encontrado.
Você deseja recuperá-lo?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>Não é possível renomear o arquivo:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>Movido o arquivo de gravação automática para:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>Movido o arquivo original para:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>Não é possível excluir o arquivo:</translation>
    </message>
    <message>
        <source>Cannot remove file: </source>
        <translation type="obsolete">Não é possível excluir arquivo: </translation>
    </message>
    <message>
        <source>Cannot rename backup file: </source>
        <translation type="obsolete">Não é possível renomear o arquivo de backup:</translation>
    </message>
    <message>
        <source>Moved autosave backup file to: </source>
        <translation type="obsolete">Renomeado arquivo gravação automática:</translation>
    </message>
    <message>
        <location line="-124"/>
        <source>Recover Files?</source>
        <translation>Recupere os Arquivos?</translation>
    </message>
    <message>
        <source>Choose Autosave Directory</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Escolha diretório gravação automática</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Autosaving to:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Gravação automática para:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translatorcomment>--google--
Caixa de diálogo de comportamento (requer reinício):</translatorcomment>
        <translation>Habilite a gravação automática</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Intervalo para gravação automática:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translatorcomment>--google--
Indique o ponto de término do eixo menor:
Indique o ponto de término do eixo menor
Termine</translatorcomment>
        <translation>min</translation>
    </message>
    <message>
        <source>Autosave Directory:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Diretório:</translation>
    </message>
    <message>
        <source>auto</source>
        <translatorcomment>--exact match--
--file: GridSettings_pt.ts--
&amp;Automático
Automático
Salta automaticamente</translatorcomment>
        <translation type="obsolete">auto</translation>
    </message>
</context>
</TS>
